==> babel-plugin-styled-jss-1.0.0.tgz: package/lib/index.js <==
'use strict';

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

function _toArray(arr) { return Array.isArray(arr) ? arr : Array.from(arr); }

/* eslint-disable no-template-curly-in-string */

var stripIndent = require('strip-indent');
var template = require('babel-template');

var prepareConfig = require('./utils/prepare-config');

module.exports = function (_ref) {
  var t = _ref.types;

  var config = void 0;

  var styledNames = new Set('styled');
  var StyledNames = new Set('Styled');

  return {
    pre: function pre() {
      if (config) {
        return;
      }

      config = prepareConfig(this.opts);
    },


    visitor: {
      ImportDefaultSpecifier: function ImportDefaultSpecifier(p) {
        var value = p.parentPath.node.source.value;


        if (value !== 'styled-jss') return;

        var _p$parentPath$node$sp = _toArray(p.parentPath.node.specifiers),
            defaultImport = _p$parentPath$node$sp[0],
            imports = _p$parentPath$node$sp.slice(1);

        styledNames.add(defaultImport.local.name);

        var StyledNode = imports.find(function (_ref2) {
          var imported = _ref2.imported;
          return imported.name === 'Styled';
        });
        if (StyledNode) {
          StyledNames.add(StyledNode.local.name);
        }
      },
      CallExpression: function CallExpression(p) {
        var _p$node = p.node,
            callee = _p$node.callee,
            args = _p$node.arguments;


        if (callee.name === 'require') {
          if (!(args[0] && args[0].value === 'styled-jss')) return;
          var id = void 0;

          if (p.parentPath.node.type === 'MemberExpression') {
            id = p.parentPath.parentPath.node.id;
          } else {
            id = p.parentPath.node.id;
          }

          if (id.type === 'Identifier') {
            styledNames.add(id.name);
          } else if (id.type === 'ObjectPattern') {
            id.properties.some(function (node) {
              if (node.key.name === 'Styled') {
                StyledNames.add(node.value.name);
                return true;
              }

              return false;
            });
          }

          return;
        }

        if (StyledNames.has(callee.name)) {
          styledNames.add(p.parentPath.node.id.name);
          return;
        }

        if (!(callee.object && styledNames.has(callee.object.name))) {
          return;
        }

        var object = callee.object,
            property = callee.property;


        p.replaceWith(t.callExpression(t.toExpression(object), [t.stringLiteral(property.name)].concat(_toConsumableArray(args))));
      },
      TaggedTemplateExpression: function TaggedTemplateExpression(p) {
        var tag = p.node.tag;


        var elem = void 0;
        var callee = void 0;

        if (tag.callee && styledNames.has(tag.callee.name)) {
          elem = t.identifier(tag.arguments[0].name);
          callee = tag.callee;
        } else if (tag.object && styledNames.has(tag.object.name)) {
          elem = t.stringLiteral(tag.property.name);
          callee = tag.object;
        } else return;

        var _p$node$quasi = p.node.quasi,
            quasis = _p$node$quasi.quasis,
            expressions = _p$node$quasi.expressions;


        var getPlaceholder = function getPlaceholder(index) {
          return 'VAR_' + index;
        };

        var strings = quasis.map(function (quasi) {
          return quasi.value.cooked;
        });
        var values = expressions.reduce(function (acc, expr, index) {
          return Object.assign(acc, _defineProperty({}, getPlaceholder(index), expr));
        }, {});

        var css = stripIndent(strings.map(function (str, index) {
          return index !== 0 ? getPlaceholder(index - 1) + str : str;
        }).join(''));

        var jssObject = config.parse(css);

        var jssObjectString = JSON.stringify(jssObject).replace(/(,|{)"(.*?)":/g, function (match, before, prop) {
          return prop.includes('VAR_') ? before + '[`' + prop.replace(/VAR_\d+/, '${$&}') + '`]:' : '' + before + prop + ':';
        }).replace(/:"(.*?)(VAR_\d+)(.*?)"/g, function (match, prev, val, next) {
          return prev || next ? ':`' + prev + '${' + val + '}' + next + '`' : ':' + val;
        });

        var res = template('(' + jssObjectString + ')')(values);

        p.replaceWith(t.callExpression(t.toExpression(callee), [elem, res.expression]));
      }
    }
  };
};

==> babel-plugin-styled-jss-2.0.0.tgz: package/lib/index.js <==
'use strict';

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

function _toArray(arr) { return Array.isArray(arr) ? arr : Array.from(arr); }

/* eslint-disable no-template-curly-in-string */

var stripIndent = require('strip-indent');
var template = require('babel-template');

var prepareConfig = require('./utils/prepare-config');

module.exports = function (_ref) {
  var t = _ref.types;

  var config = void 0;

  var styledNames = new Set('styled');
  var StyledNames = new Set('Styled');

  return {
    pre: function pre() {
      if (config) {
        return;
      }

      config = prepareConfig(this.opts);
    },


    visitor: {
      ImportDefaultSpecifier: function ImportDefaultSpecifier(p) {
        var value = p.parentPath.node.source.value;


        if (value !== 'styled-jss') return;

        var _p$parentPath$node$sp = _toArray(p.parentPath.node.specifiers),
            defaultImport = _p$parentPath$node$sp[0],
            imports = _p$parentPath$node$sp.slice(1);

        styledNames.add(defaultImport.local.name);

        var StyledNode = imports.find(function (_ref2) {
          var imported = _ref2.imported;
          return imported.name === 'Styled';
        });
        if (StyledNode) {
          StyledNames.add(StyledNode.local.name);
        }
      },
      CallExpression: function CallExpression(p) {
        var _p$node = p.node,
            callee = _p$node.callee,
            args = _p$node.arguments;


        if (callee.name === 'require') {
          if (!(args[0] && args[0].value === 'styled-jss')) return;
          var id = void 0;

          if (p.parentPath.node.type === 'MemberExpression') {
            id = p.parentPath.parentPath.node.id;
          } else {
            id = p.parentPath.node.id;
          }

          if (id.type === 'Identifier') {
            styledNames.add(id.name);
          } else if (id.type === 'ObjectPattern') {
            id.properties.some(function (node) {
              if (node.key.name === 'Styled') {
                StyledNames.add(node.value.name);
                return true;
              }

              return false;
            });
          }

          return;
        }

        if (StyledNames.has(callee.name)) {
          styledNames.add(p.parentPath.node.id.name);
          return;
        }

        if (!(callee.object && styledNames.has(callee.object.name))) {
          return;
        }

        var object = callee.object,
            property = callee.property;


        p.replaceWith(t.callExpression(t.callExpression(t.toExpression(object), [t.stringLiteral(property.name)]), [].concat(_toConsumableArray(args))));
      },
      TaggedTemplateExpression: function TaggedTemplateExpression(p) {
        var tag = p.node.tag;


        var elem = void 0;
        var callee = void 0;

        if (tag.callee && styledNames.has(tag.callee.name)) {
          elem = t.identifier(tag.arguments[0].name);
          callee = tag.callee;
        } else if (tag.object && styledNames.has(tag.object.name)) {
          elem = t.stringLiteral(tag.property.name);
          callee = tag.object;
        } else return;

        var _p$node$quasi = p.node.quasi,
            quasis = _p$node$quasi.quasis,
            expressions = _p$node$quasi.expressions;


        var getPlaceholder = function getPlaceholder(index) {
          return 'VAR_' + index;
        };

        var strings = quasis.map(function (quasi) {
          return quasi.value.cooked;
        });
        var values = expressions.reduce(function (acc, expr, index) {
          return Object.assign(acc, _defineProperty({}, getPlaceholder(index), expr));
        }, {});

        var css = stripIndent(strings.map(function (str, index) {
          return index !== 0 ? getPlaceholder(index - 1) + str : str;
        }).join(''));

        var jssObject = config.parse(css);

        var jssObjectString = JSON.stringify(jssObject).replace(/(,|{)"(.*?)":/g, function (match, before, prop) {
          return prop.includes('VAR_') ? before + '[`' + prop.replace(/VAR_\d+/, '${$&}') + '`]:' : '' + before + prop + ':';
        }).replace(/:"(.*?)(VAR_\d+)(.*?)"/g, function (match, prev, val, next) {
          return prev || next ? ':`' + prev + '${' + val + '}' + next + '`' : ':' + val;
        });

        var res = template('(' + jssObjectString + ')')(values);

        p.replaceWith(t.callExpression(t.callExpression(t.toExpression(callee), [elem]), [res.expression]));
      }
    }
  };
};
